﻿using System;
using System.Threading;
using NationalInstruments.VisaNS;

// built with VisualStudio2012
// Using .NET framework 4.5
// See file "Chamber Controller computer IO commands.xls" for a list of computer Input/Output commands recognized by Thermotron chamber controllers
// File is a member of this project 
// Must include NationalInstruments.Common and NationalInstruments.VisaNS references to compile.
// http://www.ni.com/nisearch/app/main/p/bot/no/ap/tech/lang/en/pg/1/sn/catnav:du,n8:3.25.123.1640,ssnav:ndr/
// and include NationalInstruments.VisaNS in usings (see above)

// Set chamber controller parms to:
// Terminator:  Last Input
// Send Acknowledgement: yes
// Note:  ALWAYS do a read after a write.  If no response needed, status is returned by default

namespace TCPIPchamberInputOutputUsingVISA
{
  class Program
  {
    // Set your chamber controller IP and port in the following string:
    static private string VisaTcpSocketResourceString = "TCPIP::192.168.4.97::8888::SOCKET";
    static private MessageBasedSession mbSession;

    static void Main(string[] args)
    {
      // Open session
      mbSession = (MessageBasedSession)ResourceManager.GetLocalManager().Open(VisaTcpSocketResourceString);
      // Enable character based termination and set termination character to be CarriageReturn (CR)
      mbSession.TerminationCharacterEnabled = true;
      mbSession.TerminationCharacter = 13; // CR is "\r"

      // Get Identification command:
      string strResponse = mbSession.Query("IDEN?\r");
      Console.WriteLine("Chamber identification = " + strResponse);

      // Run Manual command:
      strResponse = mbSession.Query("RUNM\r");
      Console.WriteLine("Run Manual response = " + strResponse);

      float fSetpointTemperature = 25F;

      for (int nLoop = 0; nLoop < 10; nLoop++)
      {
        Thread.Sleep(1000);
        string strSetpointTemperature = fSetpointTemperature++.ToString("000.0");
        strResponse = mbSession.Query("SETP1," + strSetpointTemperature + "\r");
        Console.WriteLine("Set Setpoint channel 1 (temperature) to " + strSetpointTemperature + ".  Response = " + strResponse);
        strResponse = mbSession.Query("PVAR1?\r");
        Console.WriteLine("Get Process Variable channel 1 (temperature) = " + strResponse);
        strResponse = mbSession.Query("SETP1?\r");
        Console.WriteLine("Get Setpoint channel 1 (temperature) = " + strResponse);
      }

      // Stop command:
      strResponse = mbSession.Query("STOP\r");
      Console.WriteLine("Stop response = " + strResponse);

      Console.WriteLine("Press <Enter> to continue");
      Console.ReadLine();
    }
  }
}
